@@ -109,6 +109,8 @@ CCanvas::~CCanvas()
 {
     QSettings cfg;
     cfg.setValue("map/showInfo",showInfo);
+    /* Otherwise we're stuck with the modified cursor. */
+    QApplication::restoreOverrideCursor();
 }
 
 
@@ -230,7 +232,7 @@ void CCanvas::setMouseMode(mouse_mode_e mode)
     switch(mode) {
 
         case eMouseMoveArea:
-            cursor = QCursor(QCursor(cursorMoveAreaHoover,0,0));
+            cursor = QCursor(cursorMoveAreaHoover,0,0);
             pfMousePressEvent   = &CCanvas::mousePressMoveArea;
             pfMouseMoveEvent    = &CCanvas::mouseMoveMoveArea;
             pfMouseReleaseEvent = &CCanvas::mouseReleaseMoveArea;
@@ -332,6 +334,7 @@ void CCanvas::paintEvent(QPaintEvent * e)
     p.begin(this);
     p.fillRect(rect(),Qt::white);
     p.setFont(gpResources->getMapFont());
+    p.setRenderHint(QPainter::Antialiasing,true);
     draw(p,true);
     p.end();
 
@@ -601,9 +604,10 @@ void CCanvas::drawWaypoints(QPainter& p)
         // draw symbol and identification text
         p.drawPixmap(pt2 + QPoint(-7,-7),(*wpt)->icon);
         if(!wptIsMoving) {
-            p.setPen(Qt::darkBlue);
+            drawText((*wpt)->ident,p,pt2 + QPoint(0,-20));
+/*            p.setPen(Qt::darkBlue);
             p.setBrush(Qt::darkBlue);
-            p.drawText(pt2 + QPoint(11,-8),(*wpt)->ident);
+            p.drawText(pt2 + QPoint(11,-8),(*wpt)->ident);*/
         }
         ++wpt;
     }
@@ -961,6 +965,11 @@ void CCanvas::drawRoutePolygon(CGarminRoute * route, bool isActRoute, QPainter&
         p.drawPolyline(line);
         p.setPen(QPen(Qt::white,1));
         p.drawPolyline(line);
+
+        QPoint pt;
+        foreach(pt, line){
+            p.drawPixmap(pt - QPoint(7,7), route->getIcon());
+        }
     }
 
 }
@@ -1645,3 +1654,25 @@ void CCanvas::slotCopyPosition()
     QClipboard *clipboard = QApplication::clipboard();
     clipboard->setText(coord->text());
 }
+
+void CCanvas::drawText(const QString& str, QPainter& p, const QPoint& center)
+{
+    QFont           f = gpResources->getMapFont();
+    QFontMetrics    fm(f);
+    QRect           r = fm.boundingRect(str);
+
+    r.moveCenter(center);
+
+    p.setPen(Qt::white);
+    p.setFont(f);
+
+    p.drawText(r.topLeft() - QPoint(-1,-1), str);
+    p.drawText(r.topLeft() - QPoint(-1,+1), str);
+    p.drawText(r.topLeft() - QPoint(+1,-1), str);
+    p.drawText(r.topLeft() - QPoint(+1,+1), str);
+
+    p.setFont(f);
+    p.setPen(Qt::darkBlue);
+    p.drawText(r.topLeft(),str);
+
+}
